dnl
dnl -----------------------------------------------------
dnl Extra autoconfig macros used to configure the XMM SAS
dnl -----------------------------------------------------
dnl
dnl Giuseppe Vacanti, November 1997
dnl
dnl (c) 1997-2007 European Space Agency
dnl
dnl $Id: aclocal.m4,v 1.13 2007/07/02 14:45:51 eojero Exp $
dnl

dnl --------------------------------------------------------------
dnl AC_CHECK_ENV(VARIABLE [, ACTION-IF-SET [, ACTION_IF_NOT_SET]])
dnl --------------------------------------------------------------
dnl Check whether a given environment variable is set.
dnl --------------------------------------------------------------

AC_DEFUN([AC_CHECK_ENV],
ifelse([$1], , ,
[AC_MSG_CHECKING([whether your environment sets $1])
ac_env_var=`echo $1`
ac_env_var_val=`eval echo '$'$1`
AC_CACHE_VAL(ac_env_var$ac_env_var,
[if test x$ac_env_var_val != "x" ; then
dnl   AC_MSG_RESULT(yes. $1 = $ac_env_var_val)
   AC_MSG_RESULT(yes)
   ac_$1_set=yes
   ac_env_path=`echo $ac_env_var_val | tr ':' ' '`
   ifelse([$2], , ,[$2])
 else
   AC_MSG_RESULT(no)
   ac_$1_set=no
   ac_env_path=
   ifelse([$3], , ,[$3])
 fi
])
]
))

dnl ----------------------------------------------------------------------
dnl AC_TRY_RUN_SCRIPT(script, [[action-if-ok] [, action-if-not-ok]])
dnl ----------------------------------------------------------------------
define(AC_FD_SCRIPT, 5)
AC_DEFUN(AC_TRY_RUN_SCRIPT,
[echo [$1] > conftest.script 
if chmod +x conftest.script && (./conftest.script; exit) 2>/dev/null
then
dnl Don't remove the temporary files here, so they can be examined.
  ifelse([$2], , :, [$2])
else
  echo "configure: failed program was:" >&AC_FD_SCRIPT
  cat conftest.script >&AC_FD_SCRIPT
ifelse([$3], , , [  rm -fr conftest.script
  $3
])dnl
fi
rm -fr conftest.script])


dnl ----------------------
dnl FTOOLS specific macros
dnl ----------------------
dnl ----------------------------------------------------------------------
dnl AX_FTOOLS_VERSION
AC_DEFUN(AX_FTOOLS_VERSION,
[ax_ftools_version=`${FVERSION:-fversion} | cut -dV -f 2`
AC_MSG_CHECKING([that FTOOLS is version $1 or better])
ax_have_this=`echo $ax_ftools_version | tr -ds '.' ''`
ax_want_that=`echo $1 | tr -ds '.' ''`
if test $ax_have_this -ge $ax_want_that  ; then
  AC_MSG_RESULT([($ax_ftools_version) yes])
  ifelse([$2], , ,[$2])
else
  AC_MSG_RESULT([($ax_ftools_version) no])
  AC_MSG_WARN(some SAS tasks require FTOOLS $1 or higher)
  ifelse([$3], , ,[$3])
fi
])


dnl --------------------
dnl perl specific macros
dnl --------------------
define(AC_FD_PERL, 5)
AC_DEFUN(AC_TRY_PERL5,
[ac_try_perl="$PERL -e 'require $1;' 1>&AC_FD_PERL"
AC_MSG_CHECKING([if you have perl version $1 or higher])
if AC_TRY_EVAL(ac_try_perl) ; then
AC_MSG_RESULT(yes.)
else
AC_MSG_RESULT(no.)
ifelse([$2], , ,[$2])
fi
])

dnl Fortran 90/95 specific macros
dnl -----------------------------
define(AC_FD_F90, 5)

dnl AC_TRY_LINK_F90(INCLUDES, FUNCTION-BODY,
dnl                [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]])
dnl Based on the original AC macro. With INCLUDES one should read a
dnl number of USE statements.
AC_DEFUN(AC_TRY_LINK_F90,
[ac_link_f90='${F90} -v -c conftest.f90 && ${CXX} -v -o conftest $CFLAGS  $LDFLAGS conftest.o $LIBS 1>&AC_FD_F90'
cat > conftest.f90 <<EOF
[$1]
program main
[$2]
END
EOF
if AC_TRY_EVAL(ac_link_f90) && test -s conftest; then
  ifelse([$3], , :, [rm -rf conftest*
  $3])
else
  echo "configure: failed program was:" >&AC_FD_F90
  cat conftest.f90 >&AC_FD_F90
ifelse([$4], , , [  rm -rf conftest*
  $4
])dnl
fi
rm -f conftest*])


dnl AC_TRY_COMPILE_F90(INCLUDES, FUNCTION-BODY,
dnl                   [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]])
AC_DEFUN(AC_TRY_COMPILE_F90,
[ac_compile_f90='${F90} -v -c conftest.f90 1>&AC_FD_F90'
cat > conftest.f90 <<EOF
[$1]
program main
[$2]
END
EOF
if AC_TRY_EVAL(ac_compile_f90); then
  ifelse([$3], , :, [rm -rf conftest*
  $3])
else
  echo "configure: failed program was:" >&AC_FD_F90
  cat conftest.f90 >&AC_FD_F90
ifelse([$4], , , [  rm -rf conftest*
  $4
])dnl
fi
rm -f conftest*])

